<p align="center">
    <a href="https://github.com/klukashka/Vaultx">
    <img src="https://github.com/user-attachments/assets/127537a2-7b7c-40a2-909c-3dddb8456c80" alt="Vaultx"> </a>
</p>
<p align="center">
    <em>Vaultx library is a Python 3.x client for HashiCorp's Vault. It is based on httpx and provides both sync and async clients</em>
</p>

<p align="center">
  <img src="https://github.com/klukashka/Vaultx/actions/workflows/run_tests.yml/badge.svg" alt="Tests status">
  <img src="https://klukashka.github.io/Vaultx/coverage.svg" alt="Coverage">
  <img src="https://img.shields.io/pypi/pyversions/Vaultx?color=dark-green" alt="Supported Python versions">
  <img src="https://img.shields.io/badge/Supported%20OS-Windows%2C%20macOS%2C%20Linux-default" alt="Supported OS">
  <img src="https://static.pepy.tech/badge/Vaultx/month" alt="Downloads per month">
</p>

---
**Documentation:** <https://klukashka.github.io/Vaultx/>

**Source code:**: <https://github.com/klukashka/Vaultx/>

---

Install Vaultx using pip:

```shell
$ pip install vaultx
```

---

<h3 align="center">
Currently in develop...
</h3>
